==> VASSAL-3.5.4-linux.tar.bz2: VASSAL-3.5.4/README.md <==
<img src="vassal-app/src/main/resources/icons/scalable/VASSAL.svg" width="100px" align="right" />

# VASSAL
> The open-source boardgame engine

[![Build Status](https://github.com/vassalengine/vassal/actions/workflows/test.yml/badge.svg)](https://github.com/vassalengine/vassal/actions)
[![License: LGPL v2](https://img.shields.io/badge/License-LGPL%20v2-blue.svg)](https://www.gnu.org/licenses/lgpl-2.0)

VASSAL is a game engine for building and playing online adaptations of board games and card games. Play live on the Internet or by email. VASSAL runs on all platforms, and is free, open-source software.

## Getting started

### Minimum Requirements

VASSAL 3.4 requires Java 11 or later.

The Windows and Mac packages have an appropriate version of Java bundled with
them, so there is no need to install Java separately on those operating
systems. On Linux, use your package manager to install Java 11 or later.

### Releases

Get the [current release](https://github.com/vassalengine/vassal/releases/latest). Read the [release notes](http://www.vassalengine.org/wiki/Release_Notes) to see what's new.

## Contributing

#### Bug reports

Please report bugs in the [Technical Support & Bugs](http://www.vassalengine.org/forum/viewforum.php?f=3) section of our forum.

#### Developer's guide

Read the [Developer's guide](developers-guide/developers-guide.adoc)

## License

This project is licensed under the terms of the [LGPLv2 license](LICENSE).

## Acknowledgments
YourKit supports open source projects with innovative and intelligent tools
for monitoring and profiling Java and .NET applications.
YourKit is the creator of
[YourKit Java Profiler](https://www.yourkit.com/java/profiler/),
[YourKit .NET Profiler](https://www.yourkit.com/.net/profiler/),
and [YourKit YouMonitor](https://www.yourkit.com/youmonitor/).

![YourKit-Logo](https://www.yourkit.com/images/yklogo.png)

==> VASSAL-3.6.2-linux.tar.bz2: VASSAL-3.6.2/README.md <==
<img src="vassal-app/src/main/resources/icons/scalable/VASSAL.svg" width="100px" align="right" />

# VASSAL
> The open-source boardgame engine

[![Build Status](https://github.com/vassalengine/vassal/actions/workflows/package.yml/badge.svg)](https://github.com/vassalengine/vassal/actions)
[![License: LGPL v2](https://img.shields.io/badge/License-LGPL%20v2-blue.svg)](https://www.gnu.org/licenses/lgpl-2.0)

VASSAL is a game engine for building and playing online adaptations of board games and card games. Play live on the Internet or by email. VASSAL runs on all platforms, and is free, open-source software.

## Getting started

### Minimum Requirements

VASSAL 3.5 requires Java 11 or later.

The Windows and Mac packages have an appropriate version of Java bundled with
them, so there is no need to install Java separately on those operating
systems. On Linux, use your package manager to install Java 11 or later.

### Releases

Get the [current release](https://github.com/vassalengine/vassal/releases/latest). Read the [release notes](https://vassalengine.org/wiki/Release_Notes) to see what's new.

## Contributing

#### Bug reports

Please report bugs in the [Technical Support & Bugs](https://forum.vassalengine.org/c/technical-support-bugs/6) section of our forum.

#### Developer's guide

Read the [Developer's guide](developers-guide/developers-guide.adoc)

## License

This project is licensed under the terms of the [LGPLv2 license](LICENSE).

## Acknowledgments
YourKit supports open source projects with innovative and intelligent tools
for monitoring and profiling Java and .NET applications.
YourKit is the creator of
[YourKit Java Profiler](https://www.yourkit.com/java/profiler/),
[YourKit .NET Profiler](https://www.yourkit.com/.net/profiler/),
and [YourKit YouMonitor](https://www.yourkit.com/youmonitor/).

![YourKit-Logo](https://www.yourkit.com/images/yklogo.png)
